"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fastify_plugin_1 = require("fastify-plugin");
const pg_1 = require("pg");
const graphql_1 = require("graphql");
const postgraphile_1 = require("postgraphile");
module.exports = fastify_plugin_1.default(async function (fastify, opts) {
    const pool = new pg_1.Pool(opts.poolConfig);
    const schema = await postgraphile_1.createPostGraphileSchema(pool, opts.schemas);
    const performQuery = async function (schema, query, variables, jwtToken, operationName) {
        var _a, _b;
        return await postgraphile_1.withPostGraphileContext({
            pgPool: pool,
            jwtToken,
            jwtSecret: (_a = opts === null || opts === void 0 ? void 0 : opts.contextOptions) === null || _a === void 0 ? void 0 : _a.jwtSecret,
            pgDefaultRole: (_b = opts === null || opts === void 0 ? void 0 : opts.contextOptions) === null || _b === void 0 ? void 0 : _b.pgDefaultRole
        }, async (context) => {
            return await graphql_1.graphql(schema, query, null, { ...context }, variables, operationName);
        });
    };
    fastify.decorateReply('graphql', async (query, variables) => {
        return await performQuery(schema, query, variables);
    });
}, { fastify: '3.x' });
